@@ -32,6 +32,7 @@ def main(args=None):
         dump_name=args.dump_name,
         keep_dump=args.keep_dump,
         host_file=args.host_file,
+        clear=args.clear_database,
         config=config
     )
 
@@ -82,6 +83,10 @@ def get_arguments(args):
                         help='File path for creating a additional log file',
                         required=False,
                         type=str)
+    parser.add_argument('-cd', '--clear-database',
+                        help='Dropping all tables before importing a new sync to get a clean database.',
+                        required=False,
+                        action='store_true')
     parser.add_argument('-t', '--type',
                         help='Defining the framework type [TYPO3, Symfony, Drupal, Wordpress]',
                         required=False,
