@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+# -*- coding: future_fstrings -*-
 
 import logging
 from db_sync_tool.utility import system
@@ -25,8 +25,8 @@ def init_logger():
     logger.setLevel(logging.DEBUG)
 
     if system.config:
-        if 'log_file' in system.config['host']:
-            fh = logging.FileHandler(system.config['host']['log_file'])
+        if 'log_file' in system.config:
+            fh = logging.FileHandler(system.config['log_file'])
             fh.setLevel(logging.DEBUG)
             logger.addHandler(fh)
             formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
